//-------------------------------------------------------//
//        Project Code : CodeLibrary
//           File Name : Lpf.cpp
//          Created on : 2022. 11. 5.
//         Description :
//              Author : KimJeongWoo
//  Last modified Date :
//-------------------------------------------------------//

#include "CodeLibMath.h"
#include "DigitalFilter/Lpf.h"



void sLpf1st::CoeffUpdate()
{
	Fcut = *pFcut;
	Wc = 2. * PI * Fcut;
	a1 = (2. - Wc * Tfsamp) / (2. + Wc * Tfsamp);
	b0 = (Wc * Tfsamp) / (2. + Wc * Tfsamp);
}

void sLpf1st::Init(float *Fcutoff, float SamplingTime, float *InData)
{
	pInData = (float *) InData;
	Tfsamp = SamplingTime;

	Wc = 0.;
	a1 = 0.;
	b0 = 0.;

	in = 0.;
	old = 0.;
	out = 0.;

	pFcut = (float *) Fcutoff;

	CoeffUpdate();
}

float sLpf1st::Run(void)
{
	in = *pInData;
	out = a1 * out + b0 * (in + old);
	old = in;

	return out;
}


void sLpf2nd::CoeffUpdate()
{
    Fcut = (float)*pFcut;
    Wc = 2. * PI * Fcut;
    zeta = 1. / (2.*(float)*pQf);

    d0 = Wc * Wc * Ts * Ts; // W^2 * Ts^2
    d1 = 4. * zeta * Wc * Ts;   // 4 * zeta * omega *Tfsamp

    a0 = (d0 + d1 + 4.);
    a1 = (2. * d0 - 8.) / a0;
    a2 = (d0 - d1 + 4.) / a0;
    b0 = d0 / a0;
    b1 = 2. * b0;
    b2 = b0;

}

void sLpf2nd::Init(float* Fcutoff, float* Qf, float SamplingTime, float* InData)
{
    pInData = (float*)InData;
    Ts = SamplingTime;
    pQf = (float*)Qf;
    zeta = 0.5 * (*pQf);
    pFcut = (float*)Fcutoff;

    Wc = 0.;
    a0 = 0.;
    a1 = 0.;
    b0 = 0.;
    b1 = 0.;
    b2 = 0.;

    in = 0.; // x[n]
    in1 = 0.; // x[n-1]
    in2 = 0.; // x[n-2]

    out = 0.;  // y[n]
    out1 = 0.;  // y[n-1]
    out2 = 0.;  // y[n-2]

    CoeffUpdate();
}

float sLpf2nd::Run(void)
{
    in = *pInData;
    out = (b0 * in + b1 * in1 + b2 * in2) - (a1 * out1 + a2 * out2);

    in2 = in1;
    in1 = in;

    out2 = out1;
    out1 = out;


    return out;
}




